@@ -3,7 +3,8 @@ from typing import List, NamedTuple, Optional, Tuple, Union
 
 from pybliometrics.scopus.superclasses import Retrieval
 from pybliometrics.scopus.utils import chained_get, check_parameter_value,\
-    get_id, detect_id_type, get_link, listify, make_int_if_possible
+    get_id, detect_id_type, get_link, listify, make_int_if_possible,\
+    parse_date_created
 
 
 class AbstractRetrieval(Retrieval):
@@ -50,19 +51,32 @@ class AbstractRetrieval(Retrieval):
     def authorgroup(self) -> Optional[List[NamedTuple]]:
         """A list of namedtuples representing the article's authors organized
         by affiliation, in the form (affiliation_id, dptid, organization,
-        city, postalcode, addresspart, country, auid, orcid, indexed_name,
-        surname, given_name).
+        city, postalcode, addresspart, country, collaboration, auid, orcid,
+        indexed_name, surname, given_name).
         If "given_name" is not present, fall back to initials.
         Note: Affiliation information might be missing or mal-assigned even
         when it looks correct in the web view.  In this case please request
-        a correction.
+        a correction.  It is generally missing for collaborations.
         """
-        out = []
+        # Information can be one of three forms:
+        # 1. A dict with one key (author) or two keys (affiliation and author)
+        # 2. A list of dicts with as in 1, one for each affiliation (incl. missing)
+        # 3. A list of two dicts with one key each (author and collaboration)
+        # Initialization
         fields = 'affiliation_id dptid organization city postalcode '\
-                 'addresspart country auid orcid indexed_name surname given_name'
+                 'addresspart country collaboration auid orcid indexed_name '\
+                 'surname given_name'
         auth = namedtuple('Author', fields)
         items = listify(self._head.get('author-group', []))
         index_path = ['preferred-name', 'ce:indexed-name']
+        # Check for collaboration
+        keys = [k for x in items for k in list(x.keys())]
+        if "collaboration" in keys:
+            collaboration = items.pop(-1)['collaboration']
+        else:
+            collaboration = {'ce:indexed-name': None}
+        # Iterate through each author-affiliation combination
+        out = []
         for item in items:
             if not item:
                 continue
@@ -78,13 +92,18 @@ class AbstractRetrieval(Retrieval):
                     given = au.get('ce:given-name', au['ce:initials'])
                 except KeyError:  # Collaboration
                     given = au.get('ce:text')
-                new = auth(affiliation_id=aff_id, organization=org,
-                           city=aff.get('city'), dptid=dep_id,
+                new = auth(affiliation_id=aff_id,
+                           organization=org,
+                           city=aff.get('city'),
+                           dptid=dep_id,
                            postalcode=aff.get('postal-code'),
                            addresspart=aff.get('address-part'),
-                           country=aff.get('country'), auid=int(au['@auid']),
+                           country=aff.get('country'),
+                           collaboration=collaboration.get('ce:indexed-name'),
+                           auid=int(au['@auid']),
                            orcid=au.get('@orcid'),
-                           surname=au.get('ce:surname'), given_name=given,
+                           surname=au.get('ce:surname'),
+                           given_name=given,
                            indexed_name=chained_get(au, index_path))
                 out.append(new)
         return out or None
@@ -206,6 +225,18 @@ class AbstractRetrieval(Retrieval):
             out.append(new)
         return out or None
 
+    @property
+    def copyright(self) -> str:
+        """The copyright statement of the document."""
+        path = ['item', 'bibrecord', 'item-info', 'copyright', '$']
+        return chained_get(self._json, path)
+
+    @property
+    def copyright_type(self) -> str:
+        """The copyright holder of the document."""
+        path = ['item', 'bibrecord', 'item-info', 'copyright', '@type']
+        return chained_get(self._json, path)
+
     @property
     def correspondence(self) -> Optional[List[NamedTuple]]:
         """List of namedtuples representing the authors to whom correspondence
@@ -238,6 +269,18 @@ class AbstractRetrieval(Retrieval):
         """The date of the cover the document is in."""
         return chained_get(self._json, ['coredata', 'prism:coverDate'])
 
+    @property
+    def date_created(self) -> Optional[Tuple[int, int, int]]:
+        """Return the description of a record.
+        Note: If this is empty, try property abstract instead.
+        """
+        path = ["item", "bibrecord", "item-info", "history"]
+        d = chained_get(self._json, path, {})
+        try:
+            return parse_date_created(d)
+        except KeyError:
+            return None
+
     @property
     def description(self) -> Optional[str]:
         """Return the description of a record.
