@@ -3,7 +3,8 @@ from typing import List, NamedTuple, Optional, Tuple, Union
 
 from pybliometrics.scopus.superclasses import Search
 from pybliometrics.scopus.utils import check_integrity, chained_get,\
-    check_parameter_value, check_field_consistency, listify, make_search_summary
+    check_parameter_value, check_field_consistency, get_freetoread, listify,\
+    make_search_summary
 
 
 class ScopusSearch(Search):
@@ -37,12 +38,13 @@ class ScopusSearch(Search):
         """
         # Initiate namedtuple with ordered list of fields
         fields = 'eid doi pii pubmed_id title subtype subtypeDescription ' \
-                 'creator afid affilname affiliation_city affiliation_country ' \
-                 'author_count author_names author_ids author_afids coverDate '\
-                 'coverDisplayDate publicationName issn source_id eIssn '\
-                 'aggregationType volume issueIdentifier article_number '\
-                 'pageRange description authkeywords citedby_count '\
-                 'openaccess freetoread freetoreadLabel fund_acr fund_no fund_sponsor'
+                 'creator afid affilname affiliation_city ' \
+                 'affiliation_country author_count author_names author_ids '\
+                 'author_afids coverDate coverDisplayDate publicationName '\
+                 'issn source_id eIssn aggregationType volume '\
+                 'issueIdentifier article_number pageRange description '\
+                 'authkeywords citedby_count openaccess freetoread '\
+                 'freetoreadLabel fund_acr fund_no fund_sponsor'
         doc = namedtuple('Document', fields)
         check_field_consistency(self._integrity, fields)
         # Parse elements one-by-one
@@ -68,15 +70,18 @@ class ScopusSearch(Search):
                 for auth in authors:
                     aff = listify(_deduplicate(auth.get('afid', [])))
                     affs.append('-'.join([d['$'] for d in aff]))
-                info["auth_afid"] = (';'.join(affs) or None)
+                if [a for a in affs if a]:
+                    info["auth_afid"] = ';'.join(affs)
+                else:
+                    info["auth_afid"] = None
             except KeyError:
                 pass
             date = item.get('prism:coverDate')
             if isinstance(date, list):
                 date = date[0].get('$')
             default = [None, {"$": None}]
-            freetoread = chained_get(item, ["freetoread", "value"], default)
-            freetoreadLabel = chained_get(item, ["freetoreadLabel", "value"], default)
+            freetoread = get_freetoread(item, ["freetoread", "value"], default)
+            freetoreadLabel = get_freetoread(item, ["freetoreadLabel", "value"], default)
             new = doc(article_number=item.get('article-number'),
                       title=item.get('dc:title'), fund_no=item.get('fund-no'),
                       fund_sponsor=item.get('fund-sponsor'),
@@ -96,8 +101,7 @@ class ScopusSearch(Search):
                       affiliation_country=info.get("aff_country"),
                       citedby_count=int(item['citedby-count']),
                       openaccess=int(item['openaccess']),
-                      freetoread=freetoread[-1]["$"],
-                      freetoreadLabel=freetoreadLabel[-1]["$"],
+                      freetoread=freetoread, freetoreadLabel=freetoreadLabel,
                       eIssn=item.get('prism:eIssn'),
                       author_count=item.get('author-count', {}).get('$'),
                       affiliation_city=info.get("aff_city"), afid=info.get("afid"),
