@@ -14,7 +14,7 @@ errors = {400: exception.Scopus400Error, 401: exception.Scopus401Error,
           502: exception.Scopus502Error}
 
 
-def get_content(url, api, params={}, **kwds):
+def get_content(url, api, params=None, **kwds):
     """Helper function to download a file and return its content.
 
     Parameters
@@ -61,9 +61,16 @@ def get_content(url, api, params={}, **kwds):
     if config.has_option('Authentication', 'InstToken'):
         token = config.get('Authentication', 'InstToken')
         header['X-ELS-Insttoken'] = token
+    params = params or {}
     params.update(**kwds)
     proxies = dict(config._sections.get("Proxy", {}))
 
+    # Replace credentials if provided
+    if "apikey" in params:
+        header['X-ELS-APIKey'] = params.pop("apikey")
+    if "insttoken" in params:
+        header['X-ELS-Insttoken'] = params.pop("insttoken")
+
     # Eventually wait bc of throttling
     if len(_throttling_params[api]) == _throttling_params[api].maxlen:
         try:
